@@ -23,6 +23,7 @@
 #define _SOPRANO_IODBC_MODEL_P_H_
 
 #include <QtCore/QMutex>
+#include <QtCore/QRegExp>
 
 #include "virtuosoqueryresultiteratorbackend.h"
 
@@ -32,11 +33,16 @@ namespace Soprano {
         class ConnectionPool;
     }
 
+    class VirtuosoModel;
+
     class VirtuosoModelPrivate
     {
     public:
         VirtuosoModelPrivate()
             : connectionPool( 0 ),
+              m_fakeBooleanRegExp( QLatin1String("([\"'])(true|false)\\1\\^\\^(<http\\://www\\.w3\\.org/2001/XMLSchema#boolean>|\\w+\\:boolean)"),
+                                   Qt::CaseInsensitive,
+                                   QRegExp::RegExp2 ),
               m_openIteratorMutex( QMutex::Recursive ) {
         }
 
@@ -59,10 +65,19 @@ namespace Soprano {
             m_openIteratorMutex.unlock();
         }
 
+        QueryResultIterator sparqlQuery( const QString& query );
+
+        QString replaceFakeTypesInQuery( const QString& query );
+
         ODBC::ConnectionPool* connectionPool;
         QList<Virtuoso::QueryResultIteratorBackend*> m_openIterators;
 
+        VirtuosoModel* q;
+
     private:
+        QRegExp m_fakeBooleanRegExp;
+        QMutex m_fakeBooleanRegExpMutex;
+
         QMutex m_openIteratorMutex;
     };
 }
